@@ -59,9 +59,11 @@ class DatabaseInfraAttr(BaseModel):
 
 	ip = models.CharField(verbose_name=_("Cloud Stack reserved ip"), max_length=255, blank=True, null=True)
 	dns = models.CharField(verbose_name=_("DNS"), max_length=255, blank=True, null=True)
-	cs_ip_id = models.CharField(verbose_name=_("Cloud Stack id"), max_length=255, blank=True, null=True)
+	cs_ip_id = models.CharField(verbose_name=_("Cloud Stack ip id"), max_length=255, blank=True, null=True)
 	is_write = models.BooleanField(verbose_name=_("Is write ip"), default=False)
 	databaseinfra = models.ForeignKey('physical.DatabaseInfra', related_name="cs_dbinfra_attributes")
+	networkapi_equipment_id = models.CharField(verbose_name=_("NetworkAPI Equipment id"), max_length=255, blank=True, null=True)
+	networkapi_ip_id = models.CharField(verbose_name=_("NetworkAPI ip id"), max_length=255, blank=True, null=True)
 
 	def __unicode__(self):
 		return "Cloud Stack reserved ip for %s" % (self.databaseinfra)
